@@ -1,7 +1,7 @@
 betabin <-
   function(data, start = c(.5,.5),
            method = c("duotrio", "tetrad", "threeAFC", "twoAFC",
-             "triangle"),
+             "triangle", "hexad", "twofive", "twofiveF"),
            vcov = TRUE, corrected = TRUE, gradTol = 1e-4, ...)
 {
   m <- match.call(expand.dots = FALSE)
@@ -17,7 +17,7 @@ betabin <-
   if(NCOL(m$data) != 2 || NROW(m$data) < 3)
     stop("'data' should have 2 columns and > 3 rows")
   method <- match.arg(method)
-  pGuess <- ifelse(method %in% c("duotrio", "twoAFC"), 1/2, 1/3)
+  pGuess <- getPguess(method)
   name <- c("mu", "gamma")
   if(any(start < 1e-3) || any(start > 1- 1e-3))
     stop("start has to be in the open interval (0, 1)")
