@@ -1,4 +1,4 @@
 
 if(require(testthat) && require(sensR)) {
-    test_package("sensR")
+    test_check("sensR")
 }
